@@ -1,11 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "pandoc-mode" "2.35"
+(define-package "pandoc-mode" "2.90.2"
   "Minor mode for interacting with Pandoc."
-  '((hydra "0.10.0")
-    (dash  "2.10.0"))
+  ()
   :url "http://joostkremers.github.io/pandoc-mode/"
-  :commit "d7f6fa119bb0e883cfd615009d197e4b87916033"
-  :revdesc "d7f6fa119bb0"
+  :commit "a131a553f48db71b0a051b6bc1d713627b2de3d9"
+  :revdesc "a131a553f48d"
   :keywords '("text" "pandoc")
   :authors '(("Joost Kremers" . "joostkremers@fastmail.fm"))
   :maintainers '(("Joost Kremers" . "joostkremers@fastmail.fm")))
